@@ -1,12 +1,38 @@
+/* ----------------------------------------------------------------------- *
+ *   
+ *   Copyright 1996-2009 The NASM Authors - All Rights Reserved
+ *   See the file AUTHORS included with the NASM distribution for
+ *   the specific copyright holders.
+ *
+ *   Redistribution and use in source and binary forms, with or without
+ *   modification, are permitted provided that the following
+ *   conditions are met:
+ *
+ *   * Redistributions of source code must retain the above copyright
+ *     notice, this list of conditions and the following disclaimer.
+ *   * Redistributions in binary form must reproduce the above
+ *     copyright notice, this list of conditions and the following
+ *     disclaimer in the documentation and/or other materials provided
+ *     with the distribution.
+ *     
+ *     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
+ *     CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
+ *     INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
+ *     MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+ *     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
+ *     CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ *     SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
+ *     NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+ *     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ *     HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ *     CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
+ *     OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
+ *     EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ * ----------------------------------------------------------------------- */
+
 /*
  * ldrdf.c - RDOFF Object File linker/loader main program.
- *
- * Copyright (c) 1996,99 Julian Hall. All rights reserved.
- * Improvements and fixes (c) 1999-2004 RET & COM Research.
- *
- * This file is distributed under the terms and conditions of the
- * GNU Lesser Public License (LGPL), version 2.1.
- * See http://www.gnu.org/copyleft/lgpl.html for details.
  */
 
 /*
@@ -37,6 +63,7 @@
 #include "collectn.h"
 #include "rdlib.h"
 #include "segtab.h"
+#include "nasmlib.h"
 
 #define LDRDF_VERSION "1.07"
 
@@ -1119,7 +1146,7 @@ void write_output(const char *filename)
         fwrite(outputseg[i].data, outputseg[i].length, 1, f);
     }
 
-    fwrite("\0\0\0\0\0\0\0\0\0\0", 10, 1, f);
+    fwritezero(10, f);
 }
 
 /* =========================================================================
@@ -1248,12 +1275,14 @@ int main(int argc, char **argv)
                     if ((p = strchr(buf, '\n')) != NULL)
                         *p = '\0';
                     if (i >= 128) {
+                        fclose(f);
                         fprintf(stderr, "ldrdf: too many input files\n");
                         exit(1);
                     }
                     *(respstrings + i) = newstr(buf);
                     argc++, i++;
                 }
+                fclose(f);
                 break;
             }
         case '2':
